pub enum errorCode {
Show 18 variants
TOO_MUCH_DATA,
INVALID_INPUT_DATA,
INVALID_SESSION_INFORMATION,
NO_APP_KEY,
NO_SESSION,
UNEXPECTED_ERROR,
INVALID_APP_KEY,
TOO_MANY_REQUESTS,
SERVICE_BUSY,
TIMEOUT_ERROR,
APP_KEY_CREATION_FAILED,
DUPLICATE_APP_NAME,
APP_CREATION_FAILED,
REQUEST_SIZE_EXCEEDS_LIMIT,
ACCESS_DENIED,
INVALID_MARKET_GROUP,
EXPOSURE_LIMIT_NOT_EXIST,
MARKET_GROUP_NOT_BLOCKED,
}Variants
TOO_MUCH_DATA
The operation requested too much data
INVALID_INPUT_DATA
Invalid input data
INVALID_SESSION_INFORMATION
The session token passed is invalid
NO_APP_KEY
An application key is required for this operation
NO_SESSION
A session token is required for this operation
UNEXPECTED_ERROR
An unexpected internal error occurred that prevented successful request processing.
INVALID_APP_KEY
The application key passed is invalid
TOO_MANY_REQUESTS
There are too many pending requests
SERVICE_BUSY
The service is currently too busy to service this request
TIMEOUT_ERROR
Internal call to downstream service timed out
APP_KEY_CREATION_FAILED
The application key creation has failed
DUPLICATE_APP_NAME
The application name specified already exists
APP_CREATION_FAILED
The application name specified is too long
REQUEST_SIZE_EXCEEDS_LIMIT
The request has exceeded the maximum allowed size
ACCESS_DENIED
The access to this functionality is not allowed
INVALID_MARKET_GROUP
Provided market group id does not identify a known market group
EXPOSURE_LIMIT_NOT_EXIST
Unable to delete/update limit as it doesn’t exist
MARKET_GROUP_NOT_BLOCKED
Unable to unblock market group after exposure limit breach, market group is not blocked